: Make sure we get executed by sh on all systems

# Display set for the Xvfb process we start up
#       FreeBSD and Solaris likes ':1' and Linux ':4'
DISPLAY=:4

# Ensure PATH has in it
#       1) the correct jre/java you want to use
#       2) access to the X executables
#       3) has the . for current directory for VisualRoute
PATH=/sbin:/usr/sbin:/usr/bin:/bin:/usr/X11R6/bin:/usr/local/bin:/Java/Live/bin:/root/vr6:.

# Setting VisualRoute install directory
VRHOME=/root/vr6

export DISPLAY PATH VRHOME

if id | grep "^uid=0(" >/dev/null 2>&1
then # user IS superuser
        echo "Commencing VisualRoute service as root."
else
        echo "Commencing VisualRoute service as something other than
root."
fi

USAGE="Usage: VisualRoute { start | stop | status }"

# Make sure the path is mounted
if [ ! -d $VRHOME ];
then
        echo "Unable to find the directory $VRHOME."
        exit
fi

# Check arguments started with
if [ ! "$1" = 'stop' ] && [ ! "$1" = 'start' ] && [ ! "$1" = 'status' ]
then
        echo $USAGE
        exit 1
fi

stop_process () {

        if [ `uname -s` = 'Linux' ]; then
           PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $4 }'`
          else
           PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $2 }'`
          fi

        if [ ! -z "$PID" ]; then
           MSG="Attempting to stop $1 with PID: $PID."
           echo "$MSG"
           /bin/kill ${PID} > /dev/null 2>&1
           fi

}

status_process () {
        if [ `uname -s` = 'Linux' ]; then
           PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $4 }'`
          else
           PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $2 }'`
          fi

        if [ ! -z "$PID" ]; then
                MSG="VisualRoute process $1 running with PID: $PID."
                echo "$MSG"
        fi
}


case "$1" in
'start')

       if [ -x /usr/X11R6/bin/Xvfb ]; then
          echo "VisualRoute starting X Virtual Frame Buffer."
          rm $VRHOME/Xvfb.log $VRHOME/console.log
          if [ `uname -s` = 'Linux' ]; then
             Xvfb $DISPLAY -fp unix/:-1 -screen 0 1152x900x8 2>>$VRHOME/Xvfb.log &
            else
             Xvfb $DISPLAY -screen 0 1152x900x8 2>>$VRHOME/Xvfb.log &
          fi
         else
          echo "Unable to find or execute Virtual Frame Buffer (Xvfb) service."
         fi

       if [ -x $VRHOME/UnixService.class ]; then
          echo "VisualRoute service starting."
          cd $VRHOME
          java -mx50331648 -classpath . UnixService >> $VRHOME/console.log &
         else
          echo "Unable to find or execute VisualRoute service."
         fi
  ;;

'status')
        if [ `uname -s` = 'Linux' ]; then
           pslist=`/bin/ps -elf | grep UnixService`
          elif [ `uname -s` = 'FreeBSD' ]; then
           pslist=`/bin/ps ajxw | grep UnixService`
          else
           pslist=`/bin/ps -ef | grep UnixService`
          fi
        echo "Checking for running VisualRoute service."
        status_process UnixService

        if [ `uname -s` = 'Linux' ]; then
           pslist=`/bin/ps -elf | grep Xvfb`
          elif [ `uname -s` = 'FreeBSD' ]; then
           pslist=`/bin/ps ajxw | grep Xvfb`
          else
           pslist=`/bin/ps -ef | grep Xvfb`
          fi
        echo "Checking for X Virtual Frame Buffer."
        status_process Xvfb
        ;;

'stop')
        if [ `uname -s` = 'Linux' ]; then
           pslist=`/bin/ps -elf | grep UnixService`
          elif [ `uname -s` = 'FreeBSD' ]; then
           pslist=`/bin/ps ajxw | grep UnixService`
          else
           pslist=`/bin/ps -ef | grep UnixService`
          fi
        echo "Attempting to stop VisualRoute service."
        stop_process UnixService

        if [ `uname -s` = 'Linux' ]; then
           pslist=`/bin/ps -elf | grep Xvfb`
          elif [ `uname -s` = 'FreeBSD' ]; then
           pslist=`/bin/ps ajxw | grep Xvfb`
          else
           pslist=`/bin/ps -ef | grep Xvfb`
          fi
        echo "Checking for X Virtual Frame Buffer."
        stop_process Xvfb
        ;;

*)
        echo $USAGE
        ;;

esac
